@@ -1,5 +1,5 @@
 /* This file is part of Conboy.
- * 
+ *
  * Copyright (C) 2009 Cornelius Hald
  *
  * Conboy is free software: you can redistribute it and/or modify
@@ -21,6 +21,7 @@
 #define CALLBACKS_H
 
 #include "note.h"
+#include "interface.h"
 
 gboolean
 on_window_delete		   (GtkObject		*window,
@@ -36,7 +37,7 @@ on_quit_button_clicked                 (GtkAction       *action,
                                         gpointer         user_data);
 
 void
-on_settings_button_clicked             (GtkAction       *action, 
+on_settings_button_clicked             (GtkAction       *action,
 		                                gpointer         user_data);
 
 void
@@ -67,6 +68,14 @@ void
 on_notes_button_clicked				   (GtkAction		*action,
 										gpointer		 user_data);
 
+void
+on_fullscreen_button_clicked		   (GtkAction		*action,
+										gpointer		 user_data);
+
+void
+on_about_button_clicked				   (GtkAction		*action,
+										gpointer		 user_data);
+
 void
 on_smaller_button_clicked			   (GtkAction		*action,
 										gpointer		 user_data);
@@ -75,6 +84,14 @@ void
 on_style_button_clicked                (GtkAction       *action,
 		                                gpointer         user_data);
 
+void
+on_back_button_clicked                 (GtkAction       *action,
+		                                gpointer         user_data);
+
+void
+on_forward_button_clicked              (GtkAction       *action,
+		                                gpointer         user_data);
+
 void
 on_font_size_radio_group_changed       (GtkRadioAction  *action,
 										GtkRadioAction  *current,
@@ -102,7 +119,7 @@ on_textview_insert_at_cursor		   (GtkTextView *text_view,
 void
 on_textbuffer_changed				   (GtkTextBuffer *buffer,
 									 	gpointer 		user_data);
-        								
+
 
 void
 update_title						   (GtkTextBuffer *buffer,
@@ -115,6 +132,13 @@ on_link_internal_tag_event				(GtkTextTag  *tag,
 										 GtkTextIter *iter,
 										 gpointer     user_data);
 
+gboolean
+on_link_url_tag_event				    (GtkTextTag  *tag,
+										 GObject     *object,
+										 GdkEvent    *event,
+										 GtkTextIter *iter,
+										 gpointer     user_data);
+
 void
 on_text_buffer_modified_changed			(GtkTextBuffer *buffer,
 										 gpointer		user_data);
@@ -160,7 +184,7 @@ on_bold_action_activated		(GtkAction	*action,
 
 
 void on_find_button_clicked(GtkAction *action, gpointer user_data);
-void on_find_bar_search(GtkWidget *widget, Note *note);
+void on_find_bar_search(GtkWidget *widget, UserInterface *ui);
 void on_find_bar_close(GtkWidget *widget, UserInterface *ui);
 
 
