@@ -26,6 +26,7 @@
 
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
+#include <gtk/gtkimcontext.h>
 #include <glib/gprintf.h>
 #include <hildon/hildon-window.h>
 #include <hildon/hildon-find-toolbar.h>
@@ -43,7 +44,7 @@
 #include "app_data.h"
 #include "settings.h"
 #include "conboy_note_buffer.h"
-
+#include "conboy_web_sync.h"
 #include "conboy_oauth.h"
 #include "note.h"
 #include "json.h"
@@ -147,6 +148,7 @@ on_orientation_changed(GdkScreen *screen, gpointer data)
 
 		/* Other */
 		gtk_text_view_set_editable(ui->view, FALSE);
+		/*hildon_gtk_text_view_set_input_mode(GTK_TEXT_VIEW(ui->view), HILDON_GTK_INPUT_MODE_FULL | HILDON_GTK_INPUT_MODE_AUTOCAP | HILDON_GTK_INPUT_MODE_NO_SCREEN_PLUGINS);*/
 
 	} else {
 		/* Toolbar */
@@ -165,6 +167,7 @@ on_orientation_changed(GdkScreen *screen, gpointer data)
 
 		/* Other */
 		gtk_text_view_set_editable(ui->view, TRUE);
+		/*hildon_gtk_text_view_set_input_mode(GTK_TEXT_VIEW(ui->view), HILDON_GTK_INPUT_MODE_FULL | HILDON_GTK_INPUT_MODE_AUTOCAP);*/
 	}
 }
 
@@ -262,265 +265,7 @@ on_font_size_changed(GConfClient *client, guint cnxn_id, GConfEntry *entry, gpoi
 	pango_font_description_free(font);
 }
 
-static GList*
-remove_by_guid(GList *list, ConboyNote *note_to_remove)
-{
-	gchar *guid;
-	g_object_get(note_to_remove, "guid", &guid, NULL);
-	ConboyNote *found_note = NULL;
-
-	GList *iter = list;
-	while (iter) {
-		ConboyNote *note = CONBOY_NOTE(iter->data);
-		gchar *other_guid;
-		g_object_get(note, "guid", &other_guid, NULL);
-		if (strcmp(guid, other_guid) == 0) {
-			found_note = note;
-		}
-		g_free(other_guid);
-		if (found_note) break;
-		iter = iter->next;
-	}
-
-	g_free(guid);
-
-	if (found_note) {
-		g_printerr("Remove note\n");
-		return g_list_remove(list, found_note);
-	} else {
-		return list;
-	}
-}
-
-typedef struct
-{
-	GtkDialog *dialog;
-	GtkProgressBar *bar;
-	GtkVBox   *box;
-	GtkLabel *label;
-	GtkButton *button;
-} DialogData;
-
-static void
-show_message (DialogData *data, gchar *msg)
-{
-	gdk_threads_enter();
-
-	gtk_widget_hide(GTK_WIDGET(data->bar));
-	gtk_label_set_markup(data->label, msg);
-	gtk_widget_set_sensitive(GTK_WIDGET(data->button), TRUE);
-
-	gdk_threads_leave();
-}
-
-static void
-pulse_bar (GtkProgressBar *bar)
-{
-	gdk_threads_enter();
-	gtk_progress_bar_pulse(bar);
-	gdk_threads_leave();
-}
-
-
-static void
-do_sync (gpointer *user_data)
-{
-	DialogData *data = (DialogData*)user_data;
-	AppData *app_data = app_data_get();
-	UserInterface *ui = app_data->note_window;
-	GtkProgressBar *bar = data->bar;
-
-
-
-	/* Save and make uneditable */
-	gdk_threads_enter();
-	gtk_text_view_set_editable(ui->view, FALSE);
-	note_save(ui);
-	gdk_threads_leave();
-
-	/* Save guid of current note */
-	gchar *guid = NULL;
-	if (ui->note != NULL) {
-		g_object_get(ui->note, "guid", &guid, NULL);
-	}
-
-
-
-
-	pulse_bar(bar);
-
-	gchar *url = settings_load_sync_base_url();
-	if (url == NULL || strcmp(url, "") == 0) {
-		show_message(data, "Please first set a URL in the settings");
-		return;
-	}
-	pulse_bar(bar);
-
-	int last_sync_rev = settings_load_last_sync_revision();
-	time_t last_sync_time = settings_load_last_sync_time();
-
-	gchar *request = g_strconcat(url, "/api/1.0/", NULL);
-
-	gchar *reply = conboy_http_get(request);
-
-	if (reply == NULL) {
-		gchar *msg = g_strconcat("Got no reply from: %s\n", request, NULL);
-		show_message(data, msg);
-		g_free(msg);
-		return;
-	}
-	g_free(request);
-	pulse_bar(bar);
-
-	/*g_printerr("Reply from /api/1.0/:: %s\n", reply);*/
-
-	gchar *api_ref = json_get_api_ref(reply);
-
-	reply = conboy_http_get(api_ref);
-
-	if (reply == NULL) {
-		gchar *msg = g_strconcat("Got no reply from: \n", api_ref, NULL);
-		show_message(data, msg);
-		g_free(msg);
-		return;
-	}
-	pulse_bar(bar);
-
-	/*g_printerr("Reply from /root/:: %s\n", reply);*/
-
-	/* Revision checks */
-	JsonUser *user = json_get_user(reply);
-	if (user->latest_sync_revision < last_sync_rev) {
-		g_printerr("U1 rev: %i   Local rev: %i\n", user->latest_sync_revision, last_sync_rev);
-		show_message(data, "Server revision older than our revision.");
-		return;
-	}
-	pulse_bar(bar);
-
-	g_printerr("###### Got User from server ########\n");
-	g_printerr("# First name: %s\n", user->first_name);
-	g_printerr("# Last name: %s\n", user->last_name);
-	g_printerr("#   Api ref: %s\n", user->api_ref);
-	g_printerr("####################################\n");
-
-	/* Create list of all local notes */
-	/* Just copy NoteStore to normal list */
-	ConboyNoteStore *note_store = app_data->note_store;
-	GList *local_notes = NULL;
-	GtkTreeIter iter;
-	if (gtk_tree_model_get_iter_first(GTK_TREE_MODEL(note_store), &iter)) do
-	{
-		ConboyNote *note;
-		gtk_tree_model_get(GTK_TREE_MODEL(note_store), &iter, NOTE_COLUMN, &note, -1);
-		local_notes = g_list_append(local_notes, note);
-		pulse_bar(bar);
-	} while (gtk_tree_model_iter_next(GTK_TREE_MODEL(note_store), &iter));
-
-
-	/* Get all notes since last syncRef*/
-	JsonNoteList *note_list = web_sync_get_notes(user, last_sync_rev);
-	last_sync_rev = note_list->latest_sync_revision;
-	pulse_bar(bar);
-
-	int added_notes = 0;
-	int changed_notes = 0;
-
-	/* Save notes */
-	GSList *notes = note_list->notes;
-	while (notes != NULL) {
-		ConboyNote *note = CONBOY_NOTE(notes->data);
-		g_printerr("Saving: %s\n", note->title);
-		/* TODO: Check for title conflicts */
-
-		conboy_storage_note_save(app_data->storage, note);
-
-		/* If not yet in the note store, add this note */
-		if (!conboy_note_store_find_by_guid(app_data->note_store, note->guid)) {
-			g_printerr("INFO: Adding note '%s' to note store\n", note->title);
-			conboy_note_store_add(app_data->note_store, note, NULL);
-			added_notes++;
-		} else {
-			g_printerr("INFO: Updating note '%s' in note store\n", note->title);
-			ConboyNote *old_note = conboy_note_store_find_by_guid(app_data->note_store, note->guid);
-			conboy_note_store_remove(app_data->note_store, old_note);
-			conboy_note_store_add(app_data->note_store, note, NULL); /* maybe copy only content from new to old note */
-			/*conboy_note_store_note_changed(app_data->note_store, note);*/
-			changed_notes++;
-		}
-
-		/* Remove from list of local notes */
-		/* Find local note and remove from list */
-		local_notes = remove_by_guid(local_notes, note);
-
-		pulse_bar(bar);
-		notes = notes->next;
-	}
-
-	/*
-	 * Remaining local notes are newer on the client.
-	 * Send them to the server
-	 */
-	gint uploaded_notes = 0;
-
-	pulse_bar(bar);
-	GError *error = NULL;
-	int sync_rev = web_sync_send_notes(local_notes, user->api_ref, last_sync_rev + 1, last_sync_time, &uploaded_notes, &error);
-	pulse_bar(bar);
-
-	gchar msg[1000];
-
-	if (!error) {
-		settings_save_last_sync_revision(sync_rev);
-		settings_save_last_sync_time(time(NULL));
-
-		g_sprintf(msg, "<b>%s</b>\n\n%s: %i\n%s: %i\n%s: %i\n%s: %i",
-				"Synchonization completed",
-				"Added notes", added_notes,
-				"Changed notes", changed_notes,
-				"Deleted notes", 0,
-				"Uploaded notes", uploaded_notes);
-
-	} else {
-		g_printerr("ERROR: %s\n", error->message);
-		g_sprintf(msg, "<b>Synchonization failed</b>\n\nError Message was:\n%s\n", error->message);
-		g_error_free(error);
-	}
-
-	/*
-	 * Sync finished
-	 */
-	g_free(api_ref);
-	g_list_free(local_notes);
-	/* TODO: Free json stuff */
-
-	/* Show message to user */
-	show_message(data, msg);
-
-	/* Try to get previous note */
-	ConboyNote *note = NULL;
-	if (guid != NULL) {
-		note = conboy_note_store_find_by_guid(app_data->note_store, guid);
-	}
-
-	/* If not possible, because it was deleted or there was no previous note, get latest */
-	if (note == NULL) {
-		note = conboy_note_store_get_latest(app_data->note_store);
-	}
-
-	if (note == NULL) {
-		/* TODO: Show demo note */
-		note = conboy_note_new();
-		g_printerr("ERROR: No notes to display\n");
-	}
-
-	/* Load again and make editable */
-	gdk_threads_enter();
-	gtk_text_view_set_editable(ui->view, TRUE);
-	note_show(note, FALSE, TRUE, FALSE);
-	gdk_threads_leave();
-}
-
-static DialogData*
+static WebSyncDialogData*
 create_sync_dialog(GtkWindow *parent)
 {
 	GtkWidget *dia = gtk_dialog_new();
@@ -546,7 +291,7 @@ create_sync_dialog(GtkWindow *parent)
 	g_signal_connect(dia, "response", G_CALLBACK(gtk_widget_destroy), NULL);
 
 	/* TODO: This data must get freed once the dialog is closed */
-	DialogData *dialog_data = g_new0(DialogData, 1);
+	WebSyncDialogData *dialog_data = g_new0(WebSyncDialogData, 1);
 	dialog_data->dialog = GTK_DIALOG(dia);
 	dialog_data->bar = GTK_PROGRESS_BAR(bar);
 	dialog_data->label = GTK_LABEL(txt);
@@ -563,12 +308,12 @@ on_sync_but_clicked(GtkButton *but, gpointer user_data)
 
 	/* Show dialog */
 	GtkWindow *parent = GTK_WINDOW(app_data->note_window->window);
-	DialogData *dialog_data = create_sync_dialog(parent);
+	WebSyncDialogData *dialog_data = create_sync_dialog(parent);
 	ui_helper_remove_portrait_support(GTK_WINDOW(dialog_data->dialog));
 	gtk_widget_show(GTK_WIDGET(dialog_data->dialog));
 
 	/* Create thread and start sync */
-	GThread *thread = g_thread_create(do_sync, dialog_data, TRUE, NULL);
+	GThread *thread = g_thread_create(web_sync_do_sync, dialog_data, TRUE, NULL);
 	if (!thread) {
 		g_printerr("ERROR: Cannot create sync thread\n");
 		return;
@@ -801,6 +546,10 @@ static gboolean
 on_preedit_changed (GSignalInvocationHint *ihint, guint n_param_values, const GValue *param_values, gpointer data)
 {
 
+	GtkIMContext *ctx;
+	hildon_gtk_im_context_hide(ctx);
+
+	/*
 	g_printerr("### Preedit parameter count: %i\n", n_param_values);
 
 	GtkIMContext *ctx = (GtkIMContext*) g_value_peek_pointer(&(param_values[0]));
@@ -820,7 +569,7 @@ on_preedit_changed (GSignalInvocationHint *ihint, guint n_param_values, const GV
 	gtk_text_buffer_get_bounds(buffer, &start, &end);
 	gchar *text = gtk_text_buffer_get_text(buffer, &start, &end, FALSE);
 	g_printerr("### TEXT: >%s<\n", text);
-
+	 */
 
 	return TRUE; /* to stay connected */
 }
@@ -1526,8 +1275,16 @@ UserInterface* create_mainwin() {
 #endif
 
 	/* Add signal hook to work with the word completion */
+
+	/*
 	guint signal_id = g_signal_lookup("preedit-changed", GTK_TYPE_IM_CONTEXT);
 	g_signal_add_emission_hook(signal_id, 0, on_preedit_changed, textview, NULL);
+	 */
+
+	/* Disable word completion (no HILDON_GTK_INPUT_MODE_DICTIONARY and no HILDON_GTK_INPUT_MODE_MULTILINE) */
+	hildon_gtk_text_view_set_input_mode(GTK_TEXT_VIEW(textview), HILDON_GTK_INPUT_MODE_FULL | HILDON_GTK_INPUT_MODE_AUTOCAP);
+
+
 
 	return ui;
 }
